import request from '@/utils/request'
// 获取列表
export function getInfo(data) {
  return request({
    url: '/doc/queryClientInfo',
    method: 'post',
    params: data
  })
}
// 增加
export function addClientInfo(data) {
  return request({
    url: '/doc/addClientInfo',
    method: 'post',
    params: data
  })
}

// 修改列表
export function updateInfo(data) {
  return request({
    url: '/doc/updateClientInfo',
    method: 'post',
    params: data
  })
}

// 通id获取详情
export function getInfoById(data) {
  return request({
    url: '/doc/getClientInfo',
    method: 'post',
    data: data
  })
}

// 前台获取发货区域List
export function getshipAreaListInfo(data) {
  return request({
    url: '/doc/getAllShipAreaEnable',
    method: 'post',
    params: data
  })
}

// 前台获取发货方式
export function getshipModeListInfo(data) {
  // console.log(data);
  return request({
    url: '/doc/getAllShipModeEnable',
    method: 'post',
    params: data
  })
}

// 前台行业信息列表
export function getIndustryInfo(data) {
  return request({
    url: '/doc/getAllClientIndustryEnable',
    method: 'post',
    params: data
  })
}

// 前台获取客户等级信息
export function getLevelInfo(data) {
  return request({
    url: '/doc/getAllClientLevelEnable',
    method: 'post',
    params: data
  })
}

// 前台获取付款方式信息
export function getPaytypeInfo(data) {
  return request({
    url: '/doc/getAllClientPayModeEnable',
    method: 'post',
    params: data
  })
}

// 获取客户地址列表
export function getAddressInfo(data) {
  return request({
    url: '/doc/queryClientReceiveAddress',
    method: 'post',
    params: data
  })
}

// 增加客户地址
export function addAddressInfo(data) {
  return request({
    url: '/doc/addClientReceiveAddress',
    method: 'post',
    params: data
  })
}

// 修改客户地址
export function updateAddressInfo(data) {
  return request({
    url: '/doc/updateClientReceiveAddress',
    method: 'post',
    params: data
  })
}

// 设置默认
export function defaultAddress(data) {
  return request({
    url: '/doc/defaultClientReceiveAddress',
    method: 'post',
    params: data
  })
}

// 删除
export function deleteAddress(data) {
  return request({
    url: '/doc/deleteClientReceiveAddress',
    method: 'post',
    params: data
  })
}

// 1、获取客户发票抬头列表
export function getClientInvoiceTitle(data) {
  return request({
    url: '/doc/getClientInvoiceTitle',
    method: 'post',
    params: data
  })
}
// 2、增加发票抬头
export function addClientInvoiceTitle(data) {
  return request({
    url: '/doc/addClientInvoiceTitle',
    method: 'post',
    params: data
  })
}

// 3、修改发票抬头
export function updateClientInvoiceTitle(data) {
  return request({
    url: '/doc/updateClientInvoiceTitle',
    method: 'post',
    params: data
  })
}

// 4、启用、禁用
export function voidClientInvoiceTitle(data) {
  return request({
    url: '/doc/voidClientInvoiceTitle',
    method: 'post',
    params: data
  })
}


